app-turbo
=========

.. image:: https://travis-ci.org/wecatch/app-turbo.svg?branch=master
    :alt: Build Status
    :target: https://travis-ci.org/wecatch/app-turbo


`Turbo <http://app-turbo.readthedocs.org>`_ is a web framework for fast building web site and RESTFul api, based on tornado, mongodb, redis.


- Easily scale up and maintain
- Rapid development for RESTFul api and web site
- Django or flask application structure
- Easily customizable
- Simple ORM for mongodb
- Logger
- Session


Getting started
----------------

.. code-block:: bash

    pip install turbo
    turbo-admin startproject <project_name>
    cd <project_name>/app-server
    python main.py


Documentation
--------------

Documentation and links to additional resources are available at http://app-turbo.readthedocs.org